---
meta:
    title: Login
    description:
layout: component
---

```html:preview
<terra-login></terra-login>

<script type="module">
  const element = document.querySelector('terra-login')

  element.addEventListener('terra-login', (e) => {
    console.log(e)
  })
</script>
```

## Examples

### First Example

TODO

### Second Example

TODO

[component-metadata:terra-login]
